==> fop2-2.24-debian-x86_64.tgz: fop2/html/js/lang_cr.js <==
lang['incoming_call']      = 'Dolazni poziv';
lang['connecting_server']  = 'Povezivanje sa serverom, broj pokusaja ';

lang['from_queue']         = "Od queue:";
lang['number']             = "Broj:";
lang['name']               = "Ime:";

lang['dial']               = 'Biraj';
lang['transfer_vmail']     = 'Proslijedi na mail';
lang['attendant_transfer'] = 'Prijenos';
lang['spy']                = 'Prisluskuj';
lang['whisper']            = 'Prisluskuj i Govori';
lang['pickup']             = "Preuzmi poziv";
lang['hangup']             = 'Prekini';
lang['filter']             = 'Filter';

lang['enter_sec_code']     = 'Detalji prijave';
lang['exten']              = 'Ekstenzija:';
lang['password']           = 'Zaporka:';

lang['confirm_hangup']     = 'Zatvori poziv';
lang['areyousure']         = 'Jeste li sigurni?';
lang['yes']                = 'Da';
lang['no']                 = 'Ne';

lang['paused']             = 'Pauza';
lang['set_information']    = 'Postavite Informaciju';
lang['member_of']          = 'Clan od ';
lang['not_available']      = 'Sustav nije dostupan u trenutku';
lang['not_connect']        = 'Nemoze se spojiti na server';
lang['one_moment']         = 'Trenutak molim';
lang['no_results']         = 'Nista nije pronadjeno';

lang['toggle_lock']        = 'Zakljucaj/Otkljucaj Konferencija';
lang['toggle_muteall']     = 'Iskljuci/Ukljuci zvuk svim korisnicima';
lang['available']          = 'Na raspolaganju';
lang['phonebook']          = 'Imenik';
lang['toggle_mute']        = 'Iskljuci/Ukljuci zvuk';
lang['kick']               = 'Izbaci korisnika';
lang['record']             = 'Snimi poziv';
lang['presence_noti']      = 'Obavijest o prisutnosti';

lang['queues']             = 'Queue-ove';
lang['extensions']         = 'Ekstenzije';
lang['trunks']             = 'Trunk-ove';
lang['conferences']        = 'Konferencije';
lang['other']              = 'Ostali';
lang['enter_state']        = 'Unesite vrijednost';
lang['parkingslots']       = 'Mjesto za parking';

lang['enter_reg_code']     = 'Unesite registracijski kod:';
lang['reg_code']     = 'Registracijski kod:';
lang['reg_name']     = 'Registracijsko ime:';

lang['remove_member']      = 'Ukloni clana';
lang['remove_member_from'] = 'Ukloni iz ';
lang['pause_member']       = 'Pauziraj Clana';
lang['unpause_member']     = 'Pokreni Clana';
lang['add_member']         = 'Dodaj u ';
lang['pickup_call']        = 'Preuzmi poziv';
lang['email_user']         = 'Posalji email';
lang['chat']               = 'Chat';
lang['notlogged']          = 'Korisnik nije logiran. Biljeska se sprema.';
lang['me']                 = 'Ja';
lang['clearchat']          = 'Rascisti prozor za Chat';
lang['note']               = 'Napomena';
lang['toggle_sound']       = 'Ukljuci/iskljuci zvuk';
lang['says']               = 'Kaze';

lang['agents']             = 'Agenti: %d';
lang['calls']              = 'Pozivi na cekanju: %d';
lang['call_connected']     = 'U razgovoru sa';
lang['changeDisplayType']  = 'Promjeni tip zaslona';

lang['voicemail']          = 'Govorna posta';
lang['vmail_new']          = 'Novo';
lang['vmail_old']          = 'Staro';
lang['vmail_work']         = 'Djelatnost';
lang['vmail_family']       = 'Obitelj';
lang['vmail_friends']      = 'Prijatelji';
lang['vmail_number']       = 'Br.';
lang['vmail_date']         = 'Data';
lang['vmail_callerid']     = 'CID';
lang['vmail_duration']     = 'Trajanje';

lang['preferences']        = 'Postavke';
lang['summary']            = 'Sazetak';
lang['detailed']           = 'Podrobnije';

lang['inactive_line']      = 'Linija %d neaktivna';
lang['inuse']              = '%d linije u uporabi';
lang['vmail_count']        = 'Novo %d, Staro %d';
lang['logout']             = 'Odjava'

lang['prefSounds']         = 'Zvuci';
lang['prefDisplay']        = 'Zaslon';

lang['labelSoundChat']     = 'Chat Zvukovi';
lang['labelSoundQueue']    = 'Queue Zvukovi';
lang['labelSoundRing']     = 'Zvukovi zvonjenja';

lang['labelDisplayQueue']          = 'Default Queue obzir:';
lang['labelDisplayDynamicLine']    = 'Dinamicna Linija Zaslona:';
lang['labelDisplayNotifyDuration'] = 'Trajanje obavijesti:';
lang['labelDisplayLanguage']       = 'Jezik:';

// Internationalization strings DATE
dateFormat.i18n = {
        dayNames: [
                "Ned", "Pon", "Uto", "Sri", "Cet", "Pet", "Sub",
                "Nedelja", "Ponedeljak", "Utorak", "Srijeda", "Cetvrtak", "Petak", "Subota"
        ],
        monthNames: [
                "Sij", "Vel", "Ozu", "Tra", "Svi", "Lip", "Srp", "Kol", "Ruj", "Lis", "Stu", "Pro",
                "Sijecanj", "Veljaca", "Ozujak", "Travanj", "Svibanj", "Lipanj", "Srpanj", "Kolovoz", "Rujan", "Listopad", "Studeni", "Prosinac"
        ]
};

==> fop2-2.29.03-debian-x86_64.tgz: fop2/html/js/lang_cr.js <==
lang['incoming_call']      = 'Dolazni poziv';
lang['connecting_server']  = 'Povezivanje sa serverom, broj pokusaja ';

lang['from_queue']         = "Od queue:";
lang['number']             = "Broj:";
lang['name']               = "Ime:";

lang['dial']               = 'Biraj';
lang['transfer_vmail']     = 'Proslijedi na mail';
lang['attendant_transfer'] = 'Prijenos';
lang['blind_transfer']     = 'Slijepi Prijenos';
lang['spy']                = 'Prisluskuj';
lang['whisper']            = 'Prisluskuj i Govori';
lang['pickup']             = "Preuzmi poziv";
lang['hangup']             = 'Prekini';
lang['filter']             = 'Filter';

lang['enter_sec_code']     = 'Detalji prijave';
lang['exten']              = 'Ekstenzija:';
lang['password']           = 'Zaporka:';

lang['confirm_hangup']     = 'Zatvori poziv';
lang['areyousure']         = 'Jeste li sigurni?';
lang['yes']                = 'Da';
lang['no']                 = 'Ne';
lang['cancel']             = 'Otkazati';
lang['accept']             = 'Prihvatiti';

lang['paused']             = 'Pauza';
lang['set_information']    = 'Postavite Informaciju';
lang['set_penalty']        = 'Kazna';
lang['member_of']          = 'Clan od ';
lang['not_available']      = 'Sustav nije dostupan u trenutku';
lang['not_connect']        = 'Nemoze se spojiti na server';
lang['one_moment']         = 'Trenutak molim';
lang['no_results']         = 'Nista nije pronadjeno';

lang['toggle_lock']        = 'Zakljucaj/Otkljucaj Konferencija';
lang['toggle_muteall']     = 'Iskljuci/Ukljuci zvuk svim korisnicima';
lang['available']          = 'Na raspolaganju';
lang['phonebook']          = 'Imenik';
lang['toggle_mute']        = 'Iskljuci/Ukljuci zvuk';
lang['kick']               = 'Izbaci korisnika';
lang['record']             = 'Snimi poziv';
lang['presence_noti']      = 'Obavijest o prisutnosti';

lang['queues']             = 'Queue-ove';
lang['extensions']         = 'Ekstenzije';
lang['trunks']             = 'Trunk-ove';
lang['conferences']        = 'Konferencije';
lang['other']              = 'Ostali';
lang['enter_state']        = 'Unesite vrijednost';
lang['parkingslots']       = 'Mjesto za parking';

lang['enter_reg_code']     = 'Unesite registracijski kod:';
lang['reg_code']     = 'Registracijski kod:';
lang['reg_name']     = 'Registracijsko ime:';

lang['remove_member']      = 'Ukloni clana';
lang['remove_member_from'] = 'Ukloni iz ';
lang['pause_member']       = 'Pauziraj Clana';
lang['unpause_member']     = 'Pokreni Clana';
lang['add_member']         = 'Dodaj u ';
lang['pickup_call']        = 'Preuzmi poziv';
lang['email_user']         = 'Posalji email';
lang['chat']               = 'Chat';
lang['notlogged']          = 'Korisnik nije logiran. Biljeska se sprema.';
lang['calls_taken']        = 'Naziva uzeti';
lang['penalty']            = 'Kazna';
lang['me']                 = 'Ja';
lang['clearchat']          = 'Rascisti prozor za Chat';
lang['note']               = 'Napomena';
lang['toggle_sound']       = 'Ukljuci/iskljuci zvuk';
lang['says']               = 'Kaze';

lang['agents']             = 'Agenti: %d';
lang['calls']              = 'Pozivi na cekanju: %d';
lang['call_connected']     = 'U razgovoru sa';
lang['changeDisplayType']  = 'Promjeni tip zaslona';

lang['voicemail']          = 'Govorna posta';
lang['vmail_new']          = 'Novo';
lang['vmail_old']          = 'Staro';
lang['vmail_work']         = 'Djelatnost';
lang['vmail_family']       = 'Obitelj';
lang['vmail_friends']      = 'Prijatelji';
lang['vmail_number']       = 'Br.';
lang['vmail_date']         = 'Data';
lang['vmail_callerid']     = 'CID';
lang['vmail_duration']     = 'Trajanje';
lang['play']               = 'Reproducirati';
lang['download']           = 'Preuzimanje';

lang['preferences']        = 'Postavke';
lang['summary']            = 'Sazetak';
lang['detailed']           = 'Podrobnije';

lang['inactive_line']      = 'Linija %d neaktivna';
lang['inuse']              = '%d linije u uporabi';
lang['vmail_count']        = 'Novo %d, Staro %d';
lang['logout']             = 'Odjava'

lang['prefSounds']         = 'Zvuci';
lang['prefDisplay']        = 'Zaslon';
lang['prefPopup']          = 'Popup';
lang['prefPhone']          = 'Telefon';

lang['labelSoundChat']     = 'Chat Zvukovi';
lang['labelSoundQueue']    = 'Queue Zvukovi';
lang['labelSoundRing']     = 'Zvukovi zvonjenja';

lang['labelDisplayQueue']          = 'Default Queue obzir';
lang['labelDisplayDynamicLine']    = 'Dinamicna Linija Zaslona';
lang['labelDisplayNotifyDuration'] = 'Trajanje obavijesti';
lang['labelDisplayLanguage']       = 'Jezik';
lang['labelAutoPopup']             = 'Automatic Popup';
lang['labelAutoAnswer']            = 'Auto Odgovor';

lang['close']                      = 'Zatvoriti';
lang['recordings']                 = 'Snimke';
lang['cdrrecords']                 = 'Povijest Poziva';

// Internationalization strings DATE
dateFormat.i18n = {
        dayNames: [
                "Ned", "Pon", "Uto", "Sri", "Cet", "Pet", "Sub",
                "Nedelja", "Ponedeljak", "Utorak", "Srijeda", "Cetvrtak", "Petak", "Subota"
        ],
        monthNames: [
                "Sij", "Vel", "Ozu", "Tra", "Svi", "Lip", "Srp", "Kol", "Ruj", "Lis", "Stu", "Pro",
                "Sijecanj", "Veljaca", "Ozujak", "Travanj", "Svibanj", "Lipanj", "Srpanj", "Kolovoz", "Rujan", "Listopad", "Studeni", "Prosinac"
        ]
};
